@@ -1,6 +1,6 @@
 """
-``approxinterpol``
-===================
+``approxinterpol.approxinterpol``
+==================================
 
 Модуль, реализующий алгоритмы аппроксимации и интерполяции.
 Представлены следующие алгоритмы аппроксимации: линейной и квадратичной функциями + аппрокс. по подвыборкам.
@@ -19,45 +19,56 @@ __all__ = ['quadratic_function', 'linear_function', 'splitting_appr',
            'newton_interpolation', 'lagrange_interpolation', 'cubic_spline_interpolation']
 
 
-def get_csv_coord(csv_path):
+def get_csv_coord(csv_path=None):
     """
     Получает на вход csv файл с координатами, разделитель - запятая, десятичная часть числа отделяется точкой
-    :param csv_path: путь до csv файла
+    :param csv_path: путь до csv файла, optional
     :return: массив вида [[x1, y1], [x2, y2], ...]
     """
     coordinates = []
-    with open(csv_path, 'r', encoding='utf-8') as f:
-        reader = csv.reader(f)
-        count = 0
-        for line in reader:
-            x = line[0]
-            y = line[1]
-            try:
-                x = float(x)
-                y = float(y)
-            except ValueError:
-                if count == 0:
-                    count += 1
-                    continue
-                else:
-                    if len(x) == 10 and '.20' in x:
+    if csv_path is None:
+        csv_path = input('Введите путь до csv-файла формата utf-8: ')
+
+    try:
+        with open(csv_path, 'r', encoding='utf-8') as f:
+            reader = csv.reader(f)
+            count = 0
+            for line in reader:
+                x = line[0]
+                y = line[1]
+                try:
+                    x = float(x)
+                    y = float(y)
+                except ValueError:
+                    if count == 0:
                         count += 1
-                        coordinates.append([x, float(y)])
+                        continue
                     else:
-                        return 'Лишние символы в координатах!'
-            else:
-                count += 1
-                coordinates.append([x, y])
+                        if len(x) == 10 and '.20' in x:
+                            count += 1
+                            coordinates.append([x, float(y)])
+                        else:
+                            return 'Лишние символы в координатах!'
+                else:
+                    count += 1
+                    coordinates.append([x, y])
+    except FileNotFoundError:
+        return 'Ошибка файла'
+    except FileExistsError:
+        return 'Ошибка файла'
+    except IOError:
+        return 'Ошибка файла'
     return coordinates
 
 
-def quadratic_function(coord, is_gauss=0):
+def quadratic_function(coord=None, is_gauss=0):
     """
         Аппроксимация квадратичной функцией.
 
         Parameters
         ----------
-        coord : координаты точек в виде массива [[x1, y1], [x2, y2], ...]
+        coord : координаты точек в виде массива [[x1, y1], [x2, y2], ...], optional
+            По дефолту выставляется None, в таком случае вам будет предложено ввести путь до csv файла.
         is_gauss : 0 or 1, optional
             Флаг, необходимый для внутреннего использования функции во время вызова функции Гаусса.
             По дефолту is_gauss=0
@@ -67,9 +78,18 @@ def quadratic_function(coord, is_gauss=0):
         answer_b : string
             Функция, полученная алгоритмом аппроксимации. В виде строки
         answer_a : array
-            Массив вида [[x1, y1, f1], [x2, y2, f2], ...]
+            Массив вида [[x1, y1, f1], [x2, y2, f2], ...], где fi - значение полученной
+            функции f в точке xi
 
     """
+    if coord is None:
+        flag = False
+        while not flag:
+            coord = get_csv_coord()
+            if isinstance(coord, str):
+                continue
+            else:
+                flag = True
     # для первого уравнения
     for_c2_1 = sum([i[0] ** 4 for i in coord])
     for_c1_1 = sum([i[0] ** 3 for i in coord])
@@ -118,23 +138,32 @@ def quadratic_function(coord, is_gauss=0):
     return answer_b, answer_a
 
 
-def linear_function(coord):
+def linear_function(coord=None):
     """
         Аппроксимация линейной функцией.
 
         Parameters
         ----------
-        coord : координаты точек в виде массива [[x1, y1], [x2, y2], ...]
+        coord : координаты точек в виде массива [[x1, y1], [x2, y2], ...], optional
+            По дефолту выставляется None, в таком случае вам будет предложено ввести путь до csv файла.
 
         Returns
         -------
         answer_b : string
             Функция, полученная алгоритмом аппроксимации. В виде строки
         answer_a : array
-            Массив вида [[x1, y1, f1], [x2, y2, f2], ...]
+            Массив вида [[x1, y1, f1], [x2, y2, f2], ...], где fi - значение полученной
+            функции f в точке xi
 
     """
-
+    if coord is None:
+        flag = False
+        while not flag:
+            coord = get_csv_coord()
+            if isinstance(coord, str):
+                continue
+            else:
+                flag = True
     ### для первого уравнения
     for_c1_1 = sum([i[0] ** 2 for i in coord])
     for_c0_1 = sum([i[0] for i in coord])
@@ -251,13 +280,14 @@ def fraction_l(s=[], i=0):
     return res
 
 
-def lagrange_interpolation(coord, delta=0):
+def lagrange_interpolation(coord=None, delta=0):
     """
         Интерполяция методом Лагранжа (для равноотстоящих и неравноотстоящих узлов).
 
         Parameters
         ----------
-        coord : координаты точек в виде массива [[x1, y1], [x2, y2], ...]
+        coord : координаты точек в виде массива [[x1, y1], [x2, y2], ...], optional
+            По дефолту выставляется None, в таком случае вам будет предложено ввести путь до csv файла.
         delta : 0 or 1, optional
             Добавляет построение точек интерполяционным методом -delta к минимальному
             и + delta к маскимальному значению от исходных координат x
@@ -267,9 +297,17 @@ def lagrange_interpolation(coord, delta=0):
         -------
         out_ans : string
             Имеет вид [expr, ans2], где expr - строковое представление функции,
-            а ans2 массив вида [[], ...]
+            а ans2 массив вида [[xi, fi], ...]
 
     """
+    if coord is None:
+        flag = False
+        while not flag:
+            coord = get_csv_coord()
+            if isinstance(coord, str):
+                continue
+            else:
+                flag = True
     l_res = dict()
     x_coord = [x[0] for x in coord]
     y_coord = [y[1] for y in coord]
@@ -325,13 +363,14 @@ def lagrange_interpolation(coord, delta=0):
     return out_ans
 
 
-def newton_interpolation(coord, delta=0):
+def newton_interpolation(coord=None, delta=0):
     """
         Интерполяция методом Ньютона.
 
         Parameters
         ----------
-        coord : координаты точек в виде массива [[x1, y1], [x2, y2], ...]
+        coord : координаты точек в виде массива [[x1, y1], [x2, y2], ...], optional
+            По дефолту выставляется None, в таком случае вам будет предложено ввести путь до csv файла.
         delta : 0 or 1, optional
             Добавляет построение точек интерполяционным методом -delta к минимальному
             и + delta к маскимальному значению от исходных координат x
@@ -341,9 +380,18 @@ def newton_interpolation(coord, delta=0):
         -------
         out_ans : string
             Имеет вид [expr, ans], где expr - строковое представление функции,
-            а ans массив вида [[], ...]
+            а ans массив вида [[xi, yi, fi], ...], если delta=0
+            и вида [[xi, fi], ...], если delta=1
 
     """
+    if coord is None:
+        flag = False
+        while not flag:
+            coord = get_csv_coord()
+            if isinstance(coord, str):
+                continue
+            else:
+                flag = True
     if check_distance(coord):
 
         # Координаты изначальных точек
@@ -408,24 +456,32 @@ def newton_interpolation(coord, delta=0):
         return 'Равноотсояние точек не соблюденно, невозможно применить метод!'
 
 
-def cubic_spline_interpolation(coord, x0=[]):
+def cubic_spline_interpolation(coord=None, x0=[]):
     """
         Интерполяция методом Кубического сплайна.
 
         Parameters
         ----------
-        coord : координаты точек в виде массива [[x1, y1], [x2, y2], ...]
+        coord : координаты точек в виде массива [[x1, y1], [x2, y2], ...], optional
+            По дефолту выставляется None, в таком случае вам будет предложено ввести путь до csv файла.
         x0 : array, optional
             Точки по x, для которых мы хотим посчитать интерполяцию
             По дефолту x0=[]
 
         Returns
         -------
-        ans : string
-            Имеет вид [expr, ans], где expr - строковое представление функции,
-            а ans массив вида [[], ...]
+        ans : ...
+            ...
 
     """
+    if coord is None:
+        flag = False
+        while not flag:
+            coord = get_csv_coord()
+            if isinstance(coord, str):
+                continue
+            else:
+                flag = True
     # Координаты изначальных точек
     x_coord = [x[0] for x in coord]
     y_coord = [y[1] for y in coord]
@@ -497,21 +553,29 @@ def cubic_spline_interpolation(coord, x0=[]):
     return ans
 
 
-def splitting_appr(coord):
+def splitting_appr(coord=None):
     """
         Алгоритм аппроксимации по подвыборкам.
 
         Parameters
         ----------
-        coord : координаты точек в виде массива [[x1, y1], [x2, y2], ...]
+        coord : координаты точек в виде массива [[x1, y1], [x2, y2], ...], optional
+            По дефолту выставляется None, в таком случае вам будет предложено ввести путь до csv файла.
 
         Returns
         -------
-        y_res : string
-            Имеет вид [expr, ans], где expr - строковое представление функции,
-            а ans массив вида [[], ...]
+        y_res : ...
+            ...
 
     """
+    if coord is None:
+        flag = False
+        while not flag:
+            coord = get_csv_coord()
+            if isinstance(coord, str):
+                continue
+            else:
+                flag = True
     # Координаты изначальных точек
     x_coord = [x[0] for x in coord]
     y_coord = np.array([y[1] for y in coord])
